#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='rdhyee_test',
      version='0.1.2',
      description='An amazing sample package for rdhyee to test stuff',
      author=None,
      author_email='Raymond Yee <raymond.yee@gmail.com>',
      url=None,
      py_modules=['rdhyee_test'],
     )
